@@ -18,6 +18,8 @@ from pathlib import Path
 class AbstractRunner(ABC):
     def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, frequence='daily', selected_algo='',algo='' ,freqly_return_pkl_filename_suffix='freqly_candels.pkl',aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200, recompute_all = True, db_path_suffix=None):
         super().__init__()
+        self.starting_date = starting_date
+        self.running_date = running_date
         self.freqly_return_pkl_filename_suffix=freqly_return_pkl_filename_suffix
         self.aggregated_pkl_file_suffix=aggregated_pkl_file_suffix
         self.aggregated_pkl_mapping_file_suffix=aggregated_pkl_mapping_file_suffix
@@ -26,9 +28,11 @@ class AbstractRunner(ABC):
         self.frequence=frequence
         self.algo=algo
         self.selected_algo=selected_algo
-        self.list_pkl_file_name = self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
-        self.aggregated_pkl_file_name = self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
-        self.aggregated_pkl_mapping_file_name = self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
+
+        self.dates_stub = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y')
+        self.list_pkl_file_name = self.dates_stub +'_' +self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
+        self.aggregated_pkl_file_name = self.dates_stub +'_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
+        self.aggregated_pkl_mapping_file_name = self.dates_stub +'_'+ self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
 
         self.local_root_directory=local_root_directory
         self.user=user
@@ -136,7 +140,11 @@ class EnsemblingSignalRunner(AbstractRunner):
                 except KeyError:
                     print('cannot read ', me_signal)
                     continue
-                freqlysig_df = self.precomputed_signals_df[me_signal]
+                try:
+                    freqlysig_df = self.precomputed_signals_df[me_signal]
+                except KeyError:
+                    print('cannot read ', me_signal)
+                    continue
                 freqlyperf_df = freqlyperf_df.to_frame()
                 freqlyperf_df.columns = ['reconstituted_perf']
                 freqlysig_df = freqlysig_df.to_frame()
